@@ -13,7 +13,7 @@ from numpy.ma import array      as numpy_ma_array
 from numpy.ma import is_masked  as numpy_ma_is_masked
 from numpy.ma import masked_all as numpy_ma_masked_all
 
-from ..functions import parse_indices, get_subspace
+from ..functions import parse_indices, get_subspace, abspath
 from ..functions import inspect as cf_inspect
 from ..constants import CONSTANTS
 
@@ -302,6 +302,10 @@ A sub-array stored in a file.
 
 '''
         self.__dict__ = kwargs
+
+        f = getattr(self, 'file', None)
+        if f is not None:
+            self.file = abspath(f)
     #--- End: def
             
     def __deepcopy__(self, memo):
@@ -637,6 +641,13 @@ class FilledArray(FileArray):
     masked_all: `bool`
 
 '''
+    def __init__(self, **kwargs):
+        '''
+        '''
+        super(FilledArray, self).__init__(**kwargs)
+        self.file = None
+    #--- End: def
+
     def __getitem__(self, indices):
         '''
 
