@@ -130,20 +130,7 @@ The amount of available physical memory.
 #--- End: if
 
 def FREE_MEMORY():
-    '''
-
-The available physical memory.
-
-If the FREE_MEMORY constant is not None then its value is returned,
-otherwise the actual amount of free memory is calculated and
-returned. In either case, the FREE_MEMORY constant is not updated. The
-FREE_MEMORY constant is set with the ``cf.SET_FREE_MEMORY`` function.
-
-Note that in the former case, the returned value is likely to differ
-from the actual amount of free memory. However, calculating the actual
-amount of free memory is expensive, so it may be desireable to set it
-once at the start of a process, ideally resetting it to None after the
-process has completed.
+    '''The available physical memory.
 
 :Returns:
 
@@ -162,42 +149,16 @@ Free memory = 80.8082618713 GiB
 >>> print 'Free memory =', cf.FREE_MEMORY()/2**30, 'GiB'
 Free memory = 88.2727928162 GiB
 
-'''
-    free_memory = CONSTANTS['FREE_MEMORY']
-
-    if free_memory is None:
-        return _free_memory()
-
-    return free_memory
-#--- End: def
-
-def SET_FREE_MEMORY(*arg):
     '''
-
-:Parameters:
-
-    arg : None, optional
-
-:Returns:
-
-    None
-
-:Examples:
-
->>> cf.SET_FREE_MEMORY()
->>> cf.SET_FREE_MEMORY(None)
-
-''' 
-    if arg:
-        CONSTANTS['FREE_MEMORY'] = arg[0]
-    else:
-        CONSTANTS['FREE_MEMORY'] = _free_memory()
+    return _free_memory()
 #--- End: def
 
 def FM_THRESHOLD():
-    '''
+    '''The amount of memory which is kept free as a temporary work space.
 
-The amount of memory which is kept free as a temporary work space.
+This is the chunk size (returned and set by `cf.CHUNKSIZE`) multiplied
+by the number of chunks of memory to be kept free (returned and set by
+`cf.MINNCFM`).
 
 .. seealso:: `cf.CHUNKSIZE`, `cf.MINNCFM`
 
@@ -214,7 +175,7 @@ The amount of memory which is kept free as a temporary work space.
 >>> cf.FM_THRESHOLD()
 20000000000.0
 
-'''
+    '''
     return CONSTANTS['FM_THRESHOLD']
 #--- End: def
 
